@@ -69,6 +69,14 @@ describe 'gnocchi::api' do
       end
     end
 
+    context 'with sync_db set to true' do
+      before do
+        params.merge!({
+          :sync_db => true})
+      end
+      it { is_expected.to contain_class('gnocchi::db::sync') }
+    end
+
     context 'with disabled service managing' do
       before do
         params.merge!({
@@ -122,91 +130,80 @@ describe 'gnocchi::api' do
 
       it_raises 'a Puppet::Error', /Invalid service_name/
     end
+
+    context 'with custom auth_uri' do
+      before do
+        params.merge!({
+          :keystone_auth_uri => 'https://foo.bar:1234/',
+        })
+      end
+      it 'should configure custom auth_uri correctly' do
+        is_expected.to contain_gnocchi_config('keystone_authtoken/auth_uri').with_value( 'https://foo.bar:1234/' )
+      end
+    end
+
+    context "with no keystone identity_uri" do
+      before do
+        params.merge!({
+          :keystone_identity_uri => false,
+        })
+      end
+      it 'configures identity_uri' do
+        is_expected.to contain_gnocchi_config('keystone_authtoken/identity_uri').with_value(nil);
+        is_expected.to contain_gnocchi_api_paste_ini('pipeline:main/pipeline').with_value('gnocchi+noauth');
+      end
+    end
+
+    context "with custom keystone identity_uri" do
+      before do
+        params.merge!({
+          :keystone_identity_uri => 'https://foo.bar:1234/',
+        })
+      end
+      it 'configures identity_uri' do
+        is_expected.to contain_gnocchi_config('keystone_authtoken/identity_uri').with_value("https://foo.bar:1234/");
+        is_expected.to contain_gnocchi_api_paste_ini('pipeline:main/pipeline').with_value('gnocchi+auth');
+      end
+    end
+
+    context "with custom keystone identity_uri and auth_uri" do
+      before do
+        params.merge!({
+          :keystone_identity_uri => 'https://foo.bar:35357/',
+          :keystone_auth_uri => 'https://foo.bar:5000/v2.0/',
+        })
+      end
+      it 'configures identity_uri and auth_uri but deprecates old auth settings' do
+        is_expected.to contain_gnocchi_config('keystone_authtoken/identity_uri').with_value("https://foo.bar:35357/");
+        is_expected.to contain_gnocchi_config('keystone_authtoken/auth_uri').with_value("https://foo.bar:5000/v2.0/");
+        is_expected.to contain_gnocchi_api_paste_ini('pipeline:main/pipeline').with_value('gnocchi+auth');
+      end
+    end
+
   end
 
-  context 'on Debian platforms' do
-    let :facts do
-      @default_facts.merge({
-        :osfamily               => 'Debian',
-        :operatingsystem        => 'Debian',
-        :operatingsystemrelease => '8.0',
-        :concat_basedir         => '/var/lib/puppet/concat',
-        :fqdn                   => 'some.host.tld',
-        :processorcount         => 2,
-      })
-    end
+  on_supported_os({
+    :supported_os => OSDefaults.get_supported_os
+  }).each do |os,facts|
+    context "on #{os}" do
+      let (:facts) do
+        facts.merge!(OSDefaults.get_facts({
+          :concat_basedir => '/var/lib/puppet/concat',
+          :processorcount => 2
+        }))
+      end
 
-    let :platform_params do
-      { :api_package_name => 'gnocchi-api',
-        :api_service_name => 'gnocchi-api' }
-    end
-
-    it_configures 'gnocchi-api'
-  end
-
-  context 'on RedHat platforms' do
-    let :facts do
-      @default_facts.merge({
-        :osfamily               => 'RedHat',
-        :operatingsystem        => 'RedHat',
-        :operatingsystemrelease => '7.1',
-        :fqdn                   => 'some.host.tld',
-        :concat_basedir         => '/var/lib/puppet/concat',
-        :processorcount         => 2,
-      })
-    end
-
-    let :platform_params do
-      { :api_package_name => 'openstack-gnocchi-api',
-        :api_service_name => 'openstack-gnocchi-api' }
-    end
-
-    it_configures 'gnocchi-api'
-  end
-
-  describe 'with custom auth_uri' do
-    let :facts do
-      @default_facts.merge({ :osfamily => 'RedHat' })
-    end
-    before do
-      params.merge!({
-        :keystone_auth_uri => 'https://foo.bar:1234/',
-      })
-    end
-    it 'should configure custom auth_uri correctly' do
-      is_expected.to contain_gnocchi_config('keystone_authtoken/auth_uri').with_value( 'https://foo.bar:1234/' )
-    end
-  end
-
-  describe "with custom keystone identity_uri" do
-    let :facts do
-      @default_facts.merge({ :osfamily => 'RedHat' })
-    end
-    before do
-      params.merge!({
-        :keystone_identity_uri => 'https://foo.bar:1234/',
-      })
-    end
-    it 'configures identity_uri' do
-      is_expected.to contain_gnocchi_config('keystone_authtoken/identity_uri').with_value("https://foo.bar:1234/");
-      is_expected.to contain_gnocchi_api_paste_ini('pipeline:main/pipeline').with_value('gnocchi+auth');
-    end
-  end
-
-  describe "with custom keystone identity_uri and auth_uri" do
-    let :facts do
-      @default_facts.merge({ :osfamily => 'RedHat' })
-    end
-    before do
-      params.merge!({
-        :keystone_identity_uri => 'https://foo.bar:35357/',
-        :keystone_auth_uri => 'https://foo.bar:5000/v2.0/',
-      })
-    end
-    it 'configures identity_uri and auth_uri but deprecates old auth settings' do
-      is_expected.to contain_gnocchi_config('keystone_authtoken/identity_uri').with_value("https://foo.bar:35357/");
-      is_expected.to contain_gnocchi_config('keystone_authtoken/auth_uri').with_value("https://foo.bar:5000/v2.0/");
-      is_expected.to contain_gnocchi_api_paste_ini('pipeline:main/pipeline').with_value('gnocchi+auth');
+      let(:platform_params) do
+        case facts[:osfamily]
+        when 'Debian'
+          { :api_package_name => 'gnocchi-api',
+            :api_service_name => 'gnocchi-api' }
+        when 'RedHat'
+          { :api_package_name => 'openstack-gnocchi-api',
+            :api_service_name => 'openstack-gnocchi-api' }
+        end
+      end
+      it_behaves_like 'gnocchi-api'
     end
   end
 
